@@ -20,7 +20,7 @@ package org.apache.maven.scm.provider.accurev.cli;
  */
 
 import static org.hamcrest.Matchers.is;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
 
 import org.junit.Test;
 
